@@ -21,7 +21,6 @@ package org.jboss.as.test.integration.domain.mixed.eap640;
 import org.jboss.as.test.integration.domain.mixed.ElytronOnlyMasterTestSuite;
 import org.jboss.as.test.integration.domain.mixed.Version;
 import org.junit.BeforeClass;
-import org.junit.Ignore;
 import org.junit.runner.RunWith;
 import org.junit.runners.Suite;
 
@@ -31,11 +30,11 @@ import org.junit.runners.Suite;
 @RunWith(Suite.class)
 @Suite.SuiteClasses(value = {ElytronOnlyMasterSmoke640TestCase.class})
 @Version(Version.AsVersion.EAP_6_4_0)
-@Ignore("Ignore until WFCORE-2882 is integrated")
 public class ElytronOnlyMaster640TestSuite extends ElytronOnlyMasterTestSuite {
 
     @BeforeClass
     public static void initializeDomain() {
+        Version.AsVersion.EAP_6_4_0.assumeMaxVM();
         ElytronOnlyMasterTestSuite.getSupport(ElytronOnlyMaster640TestSuite.class);
     }
 }
